@@ -32,7 +32,7 @@ import magic
 import pdfplumber
 from PyPDF2 import PdfFileReader, PdfFileWriter
 import io
-
+from scrapy.http.headers import Headers
 # logging.basicConfig(level=logging.INFO)
 logging.getLogger('pdfplumber').setLevel(logging.WARNING)
 logging.getLogger('PyPDF2').setLevel(logging.WARNING)
@@ -119,9 +119,6 @@ class OSSFilesStore:
             pdfFileWriter.write(file_content)
             body = file_content.getvalue()
             file_content.close()
-            # file_name = 'out00.pdf'
-            # file_content = open(f'{file_name}', 'wb')
-            # pdfFileWriter.write(file_content)
             return body
         pdf.close()
         return return_result_body()
@@ -153,8 +150,6 @@ class OssFilesPipeline(MediaPipeline):
             raise NotConfigured("At settings.py missing 'OSS_PASSWORD'")
         if not settings.get('FILES_STORE'):
             raise NotConfigured("At settings.py missing 'FILES_STORE'")
-        # if not settings.get('FILES_OSS_FILE'):
-        #     raise NotConfigured("At settings.py missing 'FILES_OSS_FILE'")
         if not settings.get('FILE_PIPE_CONFIG').get(self.__class__.__name__).get('FILES_OSS_URLS_FIELD'):
             raise NotConfigured("At settings.py missing 'FILES_OSS_URLS_FIELD'")
         if not settings.get('FILE_PIPE_CONFIG').get(self.__class__.__name__).get('FILES_OSS_RESULT_FIELD'):
@@ -170,7 +165,7 @@ class OssFilesPipeline(MediaPipeline):
         )
 
         self.page_logo_text = settings.get('FILE_PIPE_CONFIG').get(self.__class__.__name__).get('PAGE_LOGO_TEXT',None)
-        self.item_header = settings.get('FILE_PIPE_CONFIG').get(self.__class__.__name__).get('ITEM_HEADER',None)
+        self.item_header_dict = settings.get('FILE_PIPE_CONFIG').get(self.__class__.__name__).get('ITEM_HEADER',None)
         self.files_oss_file = settings.get('FILE_PIPE_CONFIG').get(self.__class__.__name__).get('FILES_OSS_FILE')
         self.if_feed = settings.get('FEEDS').attributes 
         self.file_pipe_config = file_pipe_config
@@ -265,26 +260,29 @@ class OssFilesPipeline(MediaPipeline):
         # yield item 由此函数修改切割生成请求
         if not hasattr(item,'_refer'):
             item.__setattr__('_refer','')
-        if not hasattr(item,'_cookie'):
-            item.__setattr__('_cookie','')
         if not hasattr(item,'_header'):
             item.__setattr__('_header',{})
         if self.file_pipe_config.get(self.__class__.__name__)["RESOURCE_CLASSNAME"].lower() in item.__class__.__name__.lower():
             # TAG: 由于字段长度限制,限制字段urls个数100个以内
             urls = ItemAdapter(item).get(self.file_pipe_config.get(self.__class__.__name__)["FILES_OSS_URLS_FIELD"], '').split("|") \
-                if ItemAdapter(item).get(self.file_pipe_config.get(self.__class__.__name__)["FILES_OSS_URLS_FIELD"], '') else []
+                if ItemAdapter(item).get(self.file_pipe_config.get(self.__class__.__name__)["FILES_OSS_URLS_FIELD" ], '') else []
             def request_add_params(urls):
                 for u in urls:
                     u = Request(u)
-                    if item._header:
-                        u.headers = item._header
-                        u.headers.setdefault('Referer',item._refer)
-                    if self.item_header:
+                    if item._header: 
+                        # 配置资源链接上一请求的header和referer,
+                        # 如果header中包含cookie或响应中包含set-cookie请配置COOKIE_ENABLE=False
+                        item._header['Referer']=item._refer
+                        u.headers = Headers(item._header, encoding='utf-8')
+
+                    if self.item_header_dict:
                         # 如果设置自定义ITEM_HEADER优先替换到header
-                        u.headers = self.item_header
-                    if item._cookie and not self.item_header:
-                        u.headers.setdefault('Cookie',item._cookie)
+                        for key_url in self.item_header_dict.keys():
+                            host = urlparse(u.url).netloc
+                            if key_url in host:
+                                u.headers = Headers(self.item_header_dict.get(key_url,{}),encoding ='utf-8')
                     yield u
+
             return [u for u in request_add_params(urls[:100])]
 
 
